==> haskell-fast-logger-3.2.4-34.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fast-logger
version:              3.2.4
visibility:           public
id:                   fast-logger-3.2.4-CxqhiTCbe4z8Z1RtKJsh15
key:                  fast-logger-3.2.4-CxqhiTCbe4z8Z1RtKJsh15
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/logger
synopsis:             A fast logging system
description:          A fast logging system for Haskell
category:             System
abi:                  c50d7d08f3f0f1db25ef2f8a4d770d77
exposed:              True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Internal
    System.Log.FastLogger.LoggerSet System.Log.FastLogger.Types

hidden-modules:
    System.Log.FastLogger.Imports System.Log.FastLogger.FileIO
    System.Log.FastLogger.IO System.Log.FastLogger.LogStr
    System.Log.FastLogger.MultiLogger
    System.Log.FastLogger.SingleLogger System.Log.FastLogger.Write

import-dirs:          /usr/lib/ghc-9.6.6/site-local/fast-logger-3.2.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fast-logger-3.2.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fast-logger-3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fast-logger
hs-libraries:         HSfast-logger-3.2.4-CxqhiTCbe4z8Z1RtKJsh15
depends:
    array-0.5.6.0 auto-update-0.1.6-9ryA5SLAC8xHZnIgVWhrWD
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    easy-file-0.2.5-9f5Z4LqDkdpW7ARL5ow56 filepath-1.4.300.1
    stm-2.5.1.0 text-2.0.2 unix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh
    unix-time-0.4.17-Hz2xrJUYyRaFNdjGOcUMp2

haddock-interfaces:   /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html:         /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fast-logger-3.2.4-35-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fast-logger
version:              3.2.4
visibility:           public
id:                   fast-logger-3.2.4-AXHM12y5MtZKIIwsnmTfyz
key:                  fast-logger-3.2.4-AXHM12y5MtZKIIwsnmTfyz
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/logger
synopsis:             A fast logging system
description:          A fast logging system for Haskell
category:             System
abi:                  afc8204dead6d5722338c0b7adabebae
exposed:              True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Internal
    System.Log.FastLogger.LoggerSet System.Log.FastLogger.Types

hidden-modules:
    System.Log.FastLogger.Imports System.Log.FastLogger.FileIO
    System.Log.FastLogger.IO System.Log.FastLogger.LogStr
    System.Log.FastLogger.MultiLogger
    System.Log.FastLogger.SingleLogger System.Log.FastLogger.Write

import-dirs:          /usr/lib/ghc-9.6.6/site-local/fast-logger-3.2.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fast-logger-3.2.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fast-logger-3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fast-logger
hs-libraries:         HSfast-logger-3.2.4-AXHM12y5MtZKIIwsnmTfyz
depends:
    array-0.5.6.0 auto-update-0.1.6-88T3ReDBoup7kx6uceSFG6
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    easy-file-0.2.5-IIC9DtzJ1XTGBMnNCDpijr filepath-1.4.300.1
    stm-2.5.1.0 text-2.0.2 unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
    unix-time-0.4.17-1fbhzfcTn8QIpITXkAFa5Z

haddock-interfaces:   /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html:         /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
